alias mArc XmArc
alias mArcGetPos XmArcGetPos
alias mGraph XmGraph
alias mScrolledGraph XmScrolledGraph
alias mGraph XmGraph
alias mGraphInsertRoots XmGraphInsertRoots
alias mGraphDestroyAllArcs XmGraphDestroyAllArcs
alias mGraphDestroyAllNodes XmGraphDestroyAllNodes
alias mGraphCenterAroundWidget XmGraphCenterAroundWidget
